==> kamailio_5.2.1.orig.tar.gz: kamailio-5.2.1/src/modules/ims_icscf/stats.c <==
/*
 * $Id$
 *
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 * 
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by 
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an 
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 * 
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus. 
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to 
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

#include "stats.h"

int register_stats() {
	//UAR
	if (register_stat(MOD_NAME, "uar_replies_response_time", &uar_replies_response_time,0 )
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}
	if (register_stat(MOD_NAME, "uar_replies_received", &uar_replies_received, 0) != 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}

	//LIR
	if (register_stat(MOD_NAME, "lir_replies_response_time", &lir_replies_response_time,0 )
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}
	if (register_stat(MOD_NAME, "lir_replies_received", &lir_replies_received, 0)
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}

	return 1;
}

unsigned long get_avg_uar_response_time() {

	long rpls_received = get_stat_val(uar_replies_received);
	if (!rpls_received)
		return 0;

	return get_stat_val(uar_replies_response_time)/rpls_received;
}

unsigned long get_avg_lir_response_time() {

	long rpls_received = get_stat_val(lir_replies_received);
	if (!rpls_received)
		return 0;

	return get_stat_val(lir_replies_response_time)/rpls_received;
}

==> kamailio_5.8.2.orig.tar.gz: kamailio-5.8.2/src/modules/ims_icscf/stats.c <==
/*
 * $Id$
 *
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "stats.h"

int register_stats()
{
	//UAR
	if(register_stat(MOD_NAME, "uar_replies_response_time",
			   &uar_replies_response_time, 0)
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}
	if(register_stat(MOD_NAME, "uar_replies_received", &uar_replies_received, 0)
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}

	//LIR
	if(register_stat(MOD_NAME, "lir_replies_response_time",
			   &lir_replies_response_time, 0)
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}
	if(register_stat(MOD_NAME, "lir_replies_received", &lir_replies_received, 0)
			!= 0) {
		LM_ERR("failed to register stat\n");
		return -1;
	}

	return 1;
}

unsigned long get_avg_uar_response_time()
{

	long rpls_received = get_stat_val(uar_replies_received);
	if(!rpls_received)
		return 0;

	return get_stat_val(uar_replies_response_time) / rpls_received;
}

unsigned long get_avg_lir_response_time()
{

	long rpls_received = get_stat_val(lir_replies_received);
	if(!rpls_received)
		return 0;

	return get_stat_val(lir_replies_response_time) / rpls_received;
}
